@@ -1,11 +1,5 @@
-"""
-kombu.pools
-===========
-
-Public resource pools.
-
-"""
-from __future__ import absolute_import
+"""Public resource pools."""
+from __future__ import absolute_import, unicode_literals
 
 import os
 
@@ -14,20 +8,27 @@ from itertools import chain
 from .connection import Resource
 from .five import range, values
 from .messaging import Producer
-from .utils import EqualityDict
+from .utils.collections import EqualityDict
+from .utils.compat import register_after_fork
 from .utils.functional import lazy
 
-__all__ = ['ProducerPool', 'PoolGroup', 'register_group',
-           'connections', 'producers', 'get_limit', 'set_limit', 'reset']
-_limit = [200]
-_used = [False]
+__all__ = ('ProducerPool', 'PoolGroup', 'register_group',
+           'connections', 'producers', 'get_limit', 'set_limit', 'reset')
+_limit = [10]
 _groups = []
 use_global_limit = object()
 disable_limit_protection = os.environ.get('KOMBU_DISABLE_LIMIT_PROTECTION')
 
 
+def _after_fork_cleanup_group(group):
+    group.clear()
+
+
 class ProducerPool(Resource):
+    """Pool of :class:`kombu.Producer` instances."""
+
     Producer = Producer
+    close_after_fork = True
 
     def __init__(self, connections, *args, **kwargs):
         self.connections = connections
@@ -76,9 +77,13 @@ class ProducerPool(Resource):
 
 
 class PoolGroup(EqualityDict):
+    """Collection of resource pools."""
 
-    def __init__(self, limit=None):
+    def __init__(self, limit=None, close_after_fork=True):
         self.limit = limit
+        self.close_after_fork = close_after_fork
+        if self.close_after_fork and register_after_fork is not None:
+            register_after_fork(self, _after_fork_cleanup_group)
 
     def create(self, resource, limit):
         raise NotImplementedError('PoolGroups must define ``create``')
@@ -87,29 +92,30 @@ class PoolGroup(EqualityDict):
         limit = self.limit
         if limit is use_global_limit:
             limit = get_limit()
-        if not _used[0]:
-            _used[0] = True
         k = self[resource] = self.create(resource, limit)
         return k
 
 
 def register_group(group):
+    """Register group (can be used as decorator)."""
     _groups.append(group)
     return group
 
 
 class Connections(PoolGroup):
+    """Collection of connection pools."""
 
     def create(self, connection, limit):
         return connection.Pool(limit=limit)
-connections = register_group(Connections(limit=use_global_limit))
+connections = register_group(Connections(limit=use_global_limit))  # noqa: E305
 
 
 class Producers(PoolGroup):
+    """Collection of producer pools."""
 
     def create(self, connection, limit):
         return ProducerPool(connections[connection], limit=limit)
-producers = register_group(Producers(limit=use_global_limit))
+producers = register_group(Producers(limit=use_global_limit))  # noqa: E305
 
 
 def _all_pools():
@@ -117,26 +123,23 @@ def _all_pools():
 
 
 def get_limit():
+    """Get current connection pool limit."""
     return _limit[0]
 
 
-def set_limit(limit, force=False, reset_after=False):
+def set_limit(limit, force=False, reset_after=False, ignore_errors=False):
+    """Set new connection pool limit."""
     limit = limit or 0
     glimit = _limit[0] or 0
-    if limit < glimit:
-        if not disable_limit_protection and (_used[0] and not force):
-            raise RuntimeError("Can't lower limit after pool in use.")
-        reset_after = True
     if limit != glimit:
         _limit[0] = limit
         for pool in _all_pools():
-            pool.limit = limit
-        if reset_after:
-            reset()
+            pool.resize(limit)
     return limit
 
 
 def reset(*args, **kwargs):
+    """Reset all pools by closing open resources."""
     for pool in _all_pools():
         try:
             pool.force_close_all()
@@ -144,10 +147,3 @@ def reset(*args, **kwargs):
             pass
     for group in _groups:
         group.clear()
-    _used[0] = False
-
-try:
-    from multiprocessing.util import register_after_fork
-    register_after_fork(connections, reset)
-except ImportError:  # pragma: no cover
-    pass
