@@ -6,7 +6,9 @@ import pytest
 import kombu
 from time import sleep
 
-from .common import BasicFunctionality, BaseExchangeTypes, BasePriority
+from .common import (
+    BasicFunctionality, BaseExchangeTypes, BasePriority
+)
 
 
 def get_connection(
@@ -26,6 +28,11 @@ def connection(request):
     )
 
 
+@pytest.fixture()
+def invalid_connection():
+    return kombu.Connection('redis://localhost:12345')
+
+
 @pytest.mark.env('redis')
 @pytest.mark.flaky(reruns=5, reruns_delay=2)
 class test_RedisBasicFunctionality(BasicFunctionality):
